@@ -1,4 +1,4 @@
-"""Command Management for humans."""
+"""Configurable command management for humans."""
 from . import config
 from . import hooks
 from .core import forget
@@ -7,4 +7,4 @@ from .core import register
 from .core import wake
 
 SENTINEL = object()
-"""A convenient Sentinel object."""
+"""A convenient sentinel for general use."""
