@@ -1,10 +1,7 @@
-"""Interface between ``coma`` and ``omegaconf``."""
+"""All config utilities."""
 from . import cli
 from . import io
 from .utils import (
-    ConfigDict,
-    ConfigID,
-    ConfigOrIdAndConfig,
     default_default,
     default_dest,
     default_flag,
