@@ -1,4 +1,4 @@
-"""Hook defaults and utilities for ``coma``."""
+"""Hook utilities, factories, and defaults."""
 from . import (
     config_hook,
     init_hook,
