@@ -1,34 +1,31 @@
-"""Core run hooks and utilities."""
+"""Run hook utilities, factories, and defaults."""
 from typing import Callable
 
 from .utils import hook
 
 
-def factory(run_fn_name: str = "run") -> Callable:
-    """Factory for running a command.
+def factory(attr_name: str = "run") -> Callable:
+    """Factory for creating a run hook that executes a command.
 
     Example::
 
         class Command:
-            ...
             def start(self):
                 ...
+
         with coma.forget(run_hook=True):
             coma.register("cmd", Command, run_hook=factory("start"))
 
     Args:
-        run_fn_name: The command attribute to call as the run function
+        attr_name (str): The name of the command attribute to call to execute it
 
     Returns:
         A run hook
-
-    See also:
-        * TODO(invoke; protocol) for details on run hooks
     """
 
     @hook
     def _hook(command):
-        return getattr(command, run_fn_name)()
+        return getattr(command, attr_name)()
 
     return _hook
 
@@ -36,5 +33,5 @@ def factory(run_fn_name: str = "run") -> Callable:
 default = factory()
 """Default init hook function.
 
-An alias for :func:`coma.hooks.run_hook.factory` called with default arguments.
+An alias for calling :func:`coma.hooks.run_hook.factory` with default arguments.
 """
